
/**************************************************************************************** 
 *											*
 *     Copyright (C) <2004>  <Josh J. Zelonis> <josh@dyadsecurity.com>			*
 *											*
 *											*
 *     This library is free software; you can redistribute it and/or			*
 *     modify it under the terms of the GNU Lesser General Public			*
 *     License as published by the Free Software Foundation; either			*
 *     version 2.1 of the License, or (at your option) any later version.		*
 * 											*
 *     This library is distributed in the hope that it will be useful,			*
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of			*
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU		*
 *     Lesser General Public License for more details.					*
 * 											*
 *     You should have received a copy of the GNU Lesser General Public			*
 *     License along with this library; if not, write to the Free Software		*
 *     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA	*
 *											*
 ****************************************************************************************/

drop view "response_info";

alter table "scan_bucket"
	drop constraint bktFK_scan_id;

alter table "banner"
        drop constraint bnrFK_scan_bucket_id;

alter table "os_fingerprint"
        drop constraint osfnrFK_scan_bucket_id;


drop sequence scan_bucket_id_seq;
drop sequence scan_id_seq;
drop sequence scan_queue_id_seq;

drop table "os_fingerprint";
drop table "banner";
drop table "scan_bucket";
drop table "scan";
drop table "scan_queue";


------------
-- TABLES --
------------

create sequence scan_queue_id_seq;
create table "scan_queue"
(
	"scan_queue_id"	int8 not null default nextval('scan_queue_id_seq'),
	"target"	varchar(200) not null,
	"portstr"	varchar(200) default null,
	"scanmode"	varchar(10) default null,
	"pps"		int8 default null,
	"srcaddr"	varchar(200) default null,
	"srcport"	int4 default null,
	"fantaip"	int2 default null,		-- 1: use fantaip, 0: don't use fantaip
	"fingerprint"	int2 default null,
	"brokencrc"	varchar(3) default null,
	"ipttl"		int2 default null,
	"iptos"		int2 default null,
	"repeats"	int8 default null,
	"outputmods"	varchar(200) default null,	-- database,p0f
	"extraargs"	varchar(200) default null,	-- S:no-shuffle, D:no-defpayload
	"pcapfilter"	varchar(200) default null,
	primary key("scan_queue_id")
);

create sequence scan_id_seq;
create table "scan"
(
	"scan_id"	int8 not null default nextval('scan_id_seq'),
	"s_time"	int8 not null,
	"e_time"	int8 not null,
	"addrmax"	int8 not null,
	"addrmin"	int8 not null,
	"portstr"	varchar(200) not null,
	"scanmode"	int2 not null,
	"pps"		int8 not null,
	"srcaddr"	int8 not null,
	"srcport"	int4 not null,
	"fingerprint"	int4 not null,
	"tcpflags"	int4 not null,
	"active_plgroups"int2 not null,
	"dronestr"	varchar(200) not null,
	"ipttl"		int2 not null,
	"iptos"		int2 not null,
	"ipoffset"	int4 not null,
	"repeats"	int8 default null,
	"pcapfilter"	varchar(200) not null,
	primary key("scan_id")
);

create sequence scan_bucket_id_seq;
create table "scan_bucket"
(
	"scan_bucket_id"int8 not null default nextval('scan_bucket_id_seq'),
        "scan_id"	int8 not null,
	"protocol"	int2 not null,
        "host_addr"	int8 not null, 		-- ipv4 only obviously
        "trace_addr"    int8 not null,
        "dport"         int4 not null,
        "sport"         int4 not null,
        "type"		int4 not null,
        "subtype"       int4 not null,
        "ttl"           int2 not null,
        "u_tstamp"	int8 not null,
        "u_utstamp"	int8 not null,
	primary key ("scan_bucket_id")
);

create table "os_fingerprint"
(
	"scan_bucket_id"int8 not null,
	"os"	varchar(200),
	primary key ("scan_bucket_id")
);

create table "banner"
(
	"scan_bucket_id"int8 not null,
	"banner"	varchar(200),
	primary key ("scan_bucket_id")
);


-----------------
-- CONSTRAINTS --
-----------------

alter table "banner"
	add constraint bnrFK_scan_bucket_id foreign key("scan_bucket_id")
	references "scan_bucket"("scan_bucket_id");

alter table "os_fingerprint"
	add constraint osfnrFK_scan_bucket_id foreign key("scan_bucket_id")
	references "scan_bucket"("scan_bucket_id");

alter table "scan_bucket"
	add constraint bktFK_scan_id foreign key("scan_id")
	references "scan"("scan_id");


-----------
-- VIEWS --
-----------

create view "response_info" as
	select "scan_id","protocol","host_addr","trace_addr","dport","sport","type","subtype","ttl","u_tstamp","u_utstamp","os","banner"
	from "scan_bucket","os_fingerprint","banner"
	where "scan_bucket"."scan_bucket_id" = "os_fingerprint"."scan_bucket_id" and "scan_bucket"."scan_bucket_id" = "banner"."scan_bucket_id";


-----------------------
-- STORED PROCEDURES --
-----------------------

